Method: Aws::S3Control::EndpointParameters#use_fips

Defined in:
lib/aws-sdk-s3control/endpoint_parameters.rb

#use_fipsboolean

When true, send this request to the FIPS-compliant regional endpoint. If the configured endpoint does not have a FIPS compliant endpoint, dispatching the request will return an error.

Returns:

  • (boolean)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/aws-sdk-s3control/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_fips,
  :use_dual_stack,
  :endpoint,
  :account_id,
  :requires_account_id,
  :outpost_id,
  :bucket,
  :access_point_name,
  :use_arn_region,
  :resource_arn,
  :use_s3_express_control_endpoint,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseFIPS' => :use_fips,
      'UseDualStack' => :use_dual_stack,
      'Endpoint' => :endpoint,
      'AccountId' => :account_id,
      'RequiresAccountId' => :requires_account_id,
      'OutpostId' => :outpost_id,
      'Bucket' => :bucket,
      'AccessPointName' => :access_point_name,
      'UseArnRegion' => :use_arn_region,
      'ResourceArn' => :resource_arn,
      'UseS3ExpressControlEndpoint' => :use_s3_express_control_endpoint,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:endpoint] = options[:endpoint]
    self[:account_id] = options[:account_id]
    self[:requires_account_id] = options[:requires_account_id]
    self[:outpost_id] = options[:outpost_id]
    self[:bucket] = options[:bucket]
    self[:access_point_name] = options[:access_point_name]
    self[:use_arn_region] = options[:use_arn_region]
    self[:resource_arn] = options[:resource_arn]
    self[:use_s3_express_control_endpoint] = options[:use_s3_express_control_endpoint]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      use_arn_region: config.s3_use_arn_region,
    }.merge(options))
  end
end