Class: Aws::S3Control::Types::CreateAccessPointRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID for the account that owns the specified access point.

Returns:

  • (String)


943
944
945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-s3control/types.rb', line 943

class CreateAccessPointRequest < Struct.new(
  :account_id,
  :name,
  :bucket,
  :vpc_configuration,
  :public_access_block_configuration,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the bucket that you want to associate this access point with.

For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.

For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format ‘arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>`. For example, to access the bucket reports through Outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded.

Returns:

  • (String)


943
944
945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-s3control/types.rb', line 943

class CreateAccessPointRequest < Struct.new(
  :account_id,
  :name,
  :bucket,
  :vpc_configuration,
  :public_access_block_configuration,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#bucket_account_idString

The Amazon Web Services account ID associated with the S3 bucket associated with this access point.

Returns:

  • (String)


943
944
945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-s3control/types.rb', line 943

class CreateAccessPointRequest < Struct.new(
  :account_id,
  :name,
  :bucket,
  :vpc_configuration,
  :public_access_block_configuration,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name you want to assign to this access point.

Returns:

  • (String)


943
944
945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-s3control/types.rb', line 943

class CreateAccessPointRequest < Struct.new(
  :account_id,
  :name,
  :bucket,
  :vpc_configuration,
  :public_access_block_configuration,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#public_access_block_configurationTypes::PublicAccessBlockConfiguration

The PublicAccessBlock configuration that you want to apply to the access point.



943
944
945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-s3control/types.rb', line 943

class CreateAccessPointRequest < Struct.new(
  :account_id,
  :name,
  :bucket,
  :vpc_configuration,
  :public_access_block_configuration,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configurationTypes::VpcConfiguration

If you include this field, Amazon S3 restricts access to this access point to requests from the specified virtual private cloud (VPC).

<note markdown=“1”> This is required for creating an access point for Amazon S3 on Outposts buckets.

</note>


943
944
945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-s3control/types.rb', line 943

class CreateAccessPointRequest < Struct.new(
  :account_id,
  :name,
  :bucket,
  :vpc_configuration,
  :public_access_block_configuration,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end