Class: Aws::S3Control::Types::DeleteAccessGrantsInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::DeleteAccessGrantsInstanceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
1395 1396 1397 1398 1399 |
# File 'lib/aws-sdk-s3control/types.rb', line 1395 class DeleteAccessGrantsInstanceRequest < Struct.new( :account_id) SENSITIVE = [] include Aws::Structure end |