Class: Aws::S3Control::Types::DeleteAccessGrantsInstanceResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::DeleteAccessGrantsInstanceResourcePolicyRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-s3control/types.rb', line 1408 class DeleteAccessGrantsInstanceResourcePolicyRequest < Struct.new( :account_id) SENSITIVE = [] include Aws::Structure end |