Class: Aws::S3Control::Types::DeleteAccessGrantsLocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::DeleteAccessGrantsLocationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_grants_location_id ⇒ String
The ID of the registered location that you are deregistering from your S3 Access Grants instance.
-
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
Instance Attribute Details
#access_grants_location_id ⇒ String
The ID of the registered location that you are deregistering from your S3 Access Grants instance. S3 Access Grants assigned this ID when you registered the location. S3 Access Grants assigns the ID default to the default location s3:// and assigns an auto-generated ID to other locations that you register.
1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-s3control/types.rb', line 1429 class DeleteAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id) SENSITIVE = [] include Aws::Structure end |
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
1429 1430 1431 1432 1433 1434 |
# File 'lib/aws-sdk-s3control/types.rb', line 1429 class DeleteAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id) SENSITIVE = [] include Aws::Structure end |