Class: Aws::S3Control::Types::DeleteBucketReplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::DeleteBucketReplicationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID of the Outposts bucket to delete the replication configuration for.
-
#bucket ⇒ String
Specifies the S3 on Outposts bucket to delete the replication configuration for.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID of the Outposts bucket to delete the replication configuration for.
1619 1620 1621 1622 1623 1624 |
# File 'lib/aws-sdk-s3control/types.rb', line 1619 class DeleteBucketReplicationRequest < Struct.new( :account_id, :bucket) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
Specifies the S3 on Outposts bucket to delete the replication configuration for.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format ‘arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>`. For example, to access the bucket reports through Outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded.
1619 1620 1621 1622 1623 1624 |
# File 'lib/aws-sdk-s3control/types.rb', line 1619 class DeleteBucketReplicationRequest < Struct.new( :account_id, :bucket) SENSITIVE = [] include Aws::Structure end |