Class: Aws::S3Control::Types::DescribeMultiRegionAccessPointOperationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID for the owner of the Multi-Region Access Point.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
# File 'lib/aws-sdk-s3control/types.rb', line 1917

class DescribeMultiRegionAccessPointOperationRequest < Struct.new(
  :account_id,
  :request_token_arn)
  SENSITIVE = []
  include Aws::Structure
end

#request_token_arnString

The request token associated with the request you want to know about. This request token is returned as part of the response when you make an asynchronous request. You provide this token to query about the status of the asynchronous action.

Returns:

  • (String)


1917
1918
1919
1920
1921
1922
# File 'lib/aws-sdk-s3control/types.rb', line 1917

class DescribeMultiRegionAccessPointOperationRequest < Struct.new(
  :account_id,
  :request_token_arn)
  SENSITIVE = []
  include Aws::Structure
end