Class: Aws::S3Control::Types::GetAccessPointResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_arnString

The ARN of the access point.



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#aliasString

The name or alias of the access point.



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#bucketString

The name of the bucket associated with the specified access point.



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#bucket_account_idString

The Amazon Web Services account ID associated with the S3 bucket associated with this access point.



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date and time when the specified access point was created.



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#endpointsHash<String,String>

The VPC endpoint for the access point.



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the specified access point.



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_originString

Indicates whether this access point allows access from the public internet. If VpcConfiguration is specified for this access point, then NetworkOrigin is VPC, and the access point doesn’t allow access from the public internet. Otherwise, NetworkOrigin is Internet, and the access point allows access from the public internet, subject to the access point and bucket access policies.

This will always be true for an Amazon S3 on Outposts access point



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#public_access_block_configurationTypes::PublicAccessBlockConfiguration

The PublicAccessBlock configuration that you want to apply to this Amazon S3 account. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see [The Meaning of “Public“] in the *Amazon S3 User Guide*.

This data type is not supported for Amazon S3 on Outposts.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html#access-control-block-public-access-policy-status



2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configurationTypes::VpcConfiguration

Contains the virtual private cloud (VPC) configuration for the specified access point.

<note markdown=“1”> This element is empty if this access point is an Amazon S3 on Outposts access point that is used by other Amazon Web Services.

</note>


2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
# File 'lib/aws-sdk-s3control/types.rb', line 2755

class GetAccessPointResult < Struct.new(
  :name,
  :bucket,
  :network_origin,
  :vpc_configuration,
  :public_access_block_configuration,
  :creation_date,
  :alias,
  :access_point_arn,
  :endpoints,
  :bucket_account_id)
  SENSITIVE = []
  include Aws::Structure
end