Class: Aws::S3Control::Types::GetBucketLifecycleConfigurationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::GetBucketLifecycleConfigurationResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rules ⇒ Array<Types::LifecycleRule>
Container for the lifecycle rule of the Outposts bucket.
Instance Attribute Details
#rules ⇒ Array<Types::LifecycleRule>
Container for the lifecycle rule of the Outposts bucket.
2806 2807 2808 2809 2810 |
# File 'lib/aws-sdk-s3control/types.rb', line 2806 class GetBucketLifecycleConfigurationResult < Struct.new( :rules) SENSITIVE = [] include Aws::Structure end |