Class: Aws::S3Control::Types::GetBucketVersioningResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#mfa_deleteString

Specifies whether MFA delete is enabled in the bucket versioning configuration. This element is returned only if the bucket has been configured with MFA delete. If MFA delete has never been configured for the bucket, this element is not returned.

Returns:

  • (String)


3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-s3control/types.rb', line 3021

class GetBucketVersioningResult < Struct.new(
  :status,
  :mfa_delete)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The versioning state of the S3 on Outposts bucket.

Returns:

  • (String)


3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-s3control/types.rb', line 3021

class GetBucketVersioningResult < Struct.new(
  :status,
  :mfa_delete)
  SENSITIVE = []
  include Aws::Structure
end