Method: Aws::S3Control::Types::GetDataAccessRequest#permission

Defined in:
lib/aws-sdk-s3control/types.rb

#permissionString

The type of permission granted to your S3 data, which can be set to one of the following values:

  • READ – Grant read-only access to the S3 data.

  • WRITE – Grant write-only access to the S3 data.

  • READWRITE – Grant both read and write access to the S3 data.

Returns:

  • (String)


3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
# File 'lib/aws-sdk-s3control/types.rb', line 3137

class GetDataAccessRequest < Struct.new(
  :account_id,
  :target,
  :permission,
  :duration_seconds,
  :privilege,
  :target_type)
  SENSITIVE = []
  include Aws::Structure
end