Class: Aws::S3Control::Types::GetDataAccessResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::GetDataAccessResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:credentials]
Instance Attribute Summary collapse
-
#credentials ⇒ Types::Credentials
The temporary credential token that S3 Access Grants vends.
-
#matched_grant_target ⇒ String
The S3 URI path of the data to which you are being granted temporary access credentials.
Instance Attribute Details
#credentials ⇒ Types::Credentials
The temporary credential token that S3 Access Grants vends.
3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-s3control/types.rb', line 3103 class GetDataAccessResult < Struct.new( :credentials, :matched_grant_target) SENSITIVE = [:credentials] include Aws::Structure end |
#matched_grant_target ⇒ String
The S3 URI path of the data to which you are being granted temporary access credentials.
3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-s3control/types.rb', line 3103 class GetDataAccessResult < Struct.new( :credentials, :matched_grant_target) SENSITIVE = [:credentials] include Aws::Structure end |