Class: Aws::S3Control::Types::JobOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::JobOperation
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
The operation that you want this job to perform on every object listed in the manifest. For more information about the available operations, see [Operations] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-operations.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lambda_invoke ⇒ Types::LambdaInvokeOperation
Directs the specified job to invoke an Lambda function on every object in the manifest.
-
#s3_compute_object_checksum ⇒ Types::S3ComputeObjectChecksumOperation
Directs the specified job to compute checksum values for every object in the manifest.
-
#s3_delete_object_tagging ⇒ Types::S3DeleteObjectTaggingOperation
Directs the specified job to execute a DELETE Object tagging call on every object in the manifest.
-
#s3_initiate_restore_object ⇒ Types::S3InitiateRestoreObjectOperation
Directs the specified job to initiate restore requests for every archived object in the manifest.
-
#s3_put_object_acl ⇒ Types::S3SetObjectAclOperation
Directs the specified job to run a ‘PutObjectAcl` call on every object in the manifest.
-
#s3_put_object_copy ⇒ Types::S3CopyObjectOperation
Directs the specified job to run a PUT Copy object call on every object in the manifest.
-
#s3_put_object_legal_hold ⇒ Types::S3SetObjectLegalHoldOperation
Contains the configuration for an S3 Object Lock legal hold operation that an S3 Batch Operations job passes to every object to the underlying ‘PutObjectLegalHold` API operation.
-
#s3_put_object_retention ⇒ Types::S3SetObjectRetentionOperation
Contains the configuration parameters for the Object Lock retention action for an S3 Batch Operations job.
-
#s3_put_object_tagging ⇒ Types::S3SetObjectTaggingOperation
Directs the specified job to run a PUT Object tagging call on every object in the manifest.
-
#s3_replicate_object ⇒ Types::S3ReplicateObjectOperation
Directs the specified job to invoke ‘ReplicateObject` on every object in the job’s manifest.
-
#s3_update_object_encryption ⇒ Types::S3UpdateObjectEncryptionOperation
Updates the server-side encryption type of an existing encrypted object in a general purpose bucket.
Instance Attribute Details
#lambda_invoke ⇒ Types::LambdaInvokeOperation
Directs the specified job to invoke an Lambda function on every object in the manifest.
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_compute_object_checksum ⇒ Types::S3ComputeObjectChecksumOperation
Directs the specified job to compute checksum values for every object in the manifest.
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_delete_object_tagging ⇒ Types::S3DeleteObjectTaggingOperation
Directs the specified job to execute a DELETE Object tagging call on every object in the manifest.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_initiate_restore_object ⇒ Types::S3InitiateRestoreObjectOperation
Directs the specified job to initiate restore requests for every archived object in the manifest.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_put_object_acl ⇒ Types::S3SetObjectAclOperation
Directs the specified job to run a ‘PutObjectAcl` call on every object in the manifest.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_put_object_copy ⇒ Types::S3CopyObjectOperation
Directs the specified job to run a PUT Copy object call on every object in the manifest.
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_put_object_legal_hold ⇒ Types::S3SetObjectLegalHoldOperation
Contains the configuration for an S3 Object Lock legal hold operation that an S3 Batch Operations job passes to every object to the underlying ‘PutObjectLegalHold` API operation. For more information, see [Using S3 Object Lock legal hold with S3 Batch Operations] in the *Amazon S3 User Guide*.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-legal-hold.html
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_put_object_retention ⇒ Types::S3SetObjectRetentionOperation
Contains the configuration parameters for the Object Lock retention action for an S3 Batch Operations job. Batch Operations passes every object to the underlying ‘PutObjectRetention` API operation. For more information, see [Using S3 Object Lock retention with S3 Batch Operations] in the *Amazon S3 User Guide*.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-retention-date.html
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_put_object_tagging ⇒ Types::S3SetObjectTaggingOperation
Directs the specified job to run a PUT Object tagging call on every object in the manifest.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_replicate_object ⇒ Types::S3ReplicateObjectOperation
Directs the specified job to invoke ‘ReplicateObject` on every object in the job’s manifest.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |
#s3_update_object_encryption ⇒ Types::S3UpdateObjectEncryptionOperation
Updates the server-side encryption type of an existing encrypted object in a general purpose bucket. You can use the ‘UpdateObjectEncryption` operation to change encrypted objects from server-side encryption with Amazon S3 managed keys (SSE-S3) to server-side encryption with Key Management Service (KMS) keys (SSE-KMS), or to apply S3 Bucket Keys. You can also use the `UpdateObjectEncryption` operation to change the customer-managed KMS key used to encrypt your data so that you can comply with custom key-rotation standards.
4267 4268 4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-s3control/types.rb', line 4267 class JobOperation < Struct.new( :lambda_invoke, :s3_put_object_copy, :s3_put_object_acl, :s3_put_object_tagging, :s3_delete_object_tagging, :s3_initiate_restore_object, :s3_put_object_legal_hold, :s3_put_object_retention, :s3_replicate_object, :s3_compute_object_checksum, :s3_update_object_encryption) SENSITIVE = [] include Aws::Structure end |