Class: Aws::S3Control::Types::LambdaInvokeOperation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Contains the configuration parameters for a ‘Lambda Invoke` operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_arnString

The Amazon Resource Name (ARN) for the Lambda function that the specified job will invoke on every object in the manifest.

Returns:

  • (String)


4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-s3control/types.rb', line 4178

class LambdaInvokeOperation < Struct.new(
  :function_arn,
  :invocation_schema_version,
  :user_arguments)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_schema_versionString

Specifies the schema version for the payload that Batch Operations sends when invoking an Lambda function. Version 1.0 is the default. Version 2.0 is required when you use Batch Operations to invoke Lambda functions that act on directory buckets, or if you need to specify UserArguments. For more information, see [Using Lambda with Amazon S3 Batch Operations and Amazon S3 Express One Zone] in the *Amazon Web Services Storage Blog*.

Ensure that your Lambda function code expects InvocationSchemaVersion 2.0 and uses bucket name rather than bucket ARN. If the InvocationSchemaVersion does not match what your Lambda function expects, your function might not work as expected.

<note markdown=“1”> **Directory buckets** - To initiate Amazon Web Services Lambda function to perform custom actions on objects in directory buckets, you must specify 2.0.

</note>

[1]: aws.amazon.com/blogs/storage/using-lambda-with-s3-batch-operations-and-s3-express-one-zone/

Returns:

  • (String)


4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-s3control/types.rb', line 4178

class LambdaInvokeOperation < Struct.new(
  :function_arn,
  :invocation_schema_version,
  :user_arguments)
  SENSITIVE = []
  include Aws::Structure
end

#user_argumentsHash<String,String>

Key-value pairs that are passed in the payload that Batch Operations sends when invoking an Lambda function. You must specify InvocationSchemaVersion 2.0 for LambdaInvoke operations that include UserArguments. For more information, see [Using Lambda with Amazon S3 Batch Operations and Amazon S3 Express One Zone] in the *Amazon Web Services Storage Blog*.

[1]: aws.amazon.com/blogs/storage/using-lambda-with-s3-batch-operations-and-s3-express-one-zone/

Returns:

  • (Hash<String,String>)


4178
4179
4180
4181
4182
4183
4184
# File 'lib/aws-sdk-s3control/types.rb', line 4178

class LambdaInvokeOperation < Struct.new(
  :function_arn,
  :invocation_schema_version,
  :user_arguments)
  SENSITIVE = []
  include Aws::Structure
end