Class: Aws::S3Control::Types::ListCallerAccessGrantsResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#caller_access_grants_listArray<Types::ListCallerAccessGrantsEntry>

A list of the caller’s access grants that were created using S3 Access Grants and that grant the caller access to the S3 data of the Amazon Web Services account ID that was specified in the request.



5343
5344
5345
5346
5347
5348
# File 'lib/aws-sdk-s3control/types.rb', line 5343

class ListCallerAccessGrantsResult < Struct.new(
  :next_token,
  :caller_access_grants_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token that you can use to request the next page of results. Pass this value into a subsequent ‘List Caller Access Grants` request in order to retrieve the next page of results.

Returns:

  • (String)


5343
5344
5345
5346
5347
5348
# File 'lib/aws-sdk-s3control/types.rb', line 5343

class ListCallerAccessGrantsResult < Struct.new(
  :next_token,
  :caller_access_grants_list)
  SENSITIVE = []
  include Aws::Structure
end