Class: Aws::S3Control::Types::ListRegionalBucketsResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

NextToken is sent when isTruncated is true, which means there are more buckets that can be listed. The next list requests to Amazon S3 can be continued with this NextToken. NextToken is obfuscated and is not a real key.

Returns:

  • (String)


5495
5496
5497
5498
5499
5500
# File 'lib/aws-sdk-s3control/types.rb', line 5495

class ListRegionalBucketsResult < Struct.new(
  :regional_bucket_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#regional_bucket_listArray<Types::RegionalBucket>

Returns:



5495
5496
5497
5498
5499
5500
# File 'lib/aws-sdk-s3control/types.rb', line 5495

class ListRegionalBucketsResult < Struct.new(
  :regional_bucket_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end