Class: Aws::S3Control::Types::NoncurrentVersionExpiration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::NoncurrentVersionExpiration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
The container of the noncurrent version expiration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#newer_noncurrent_versions ⇒ Integer
Specifies how many noncurrent versions S3 on Outposts will retain.
-
#noncurrent_days ⇒ Integer
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action.
Instance Attribute Details
#newer_noncurrent_versions ⇒ Integer
Specifies how many noncurrent versions S3 on Outposts will retain. If there are this many more recent noncurrent versions, S3 on Outposts will take the associated action. For more information about noncurrent versions, see [Lifecycle configuration elements] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/intro-lifecycle-rules.html
5474 5475 5476 5477 5478 5479 |
# File 'lib/aws-sdk-s3control/types.rb', line 5474 class NoncurrentVersionExpiration < Struct.new( :noncurrent_days, :newer_noncurrent_versions) SENSITIVE = [] include Aws::Structure end |
#noncurrent_days ⇒ Integer
Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. For information about the noncurrent days calculations, see [How Amazon S3 Calculates When an Object Became Noncurrent] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations
5474 5475 5476 5477 5478 5479 |
# File 'lib/aws-sdk-s3control/types.rb', line 5474 class NoncurrentVersionExpiration < Struct.new( :noncurrent_days, :newer_noncurrent_versions) SENSITIVE = [] include Aws::Structure end |