Class: Aws::S3Control::Types::ObjectLambdaAccessPointAlias
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::ObjectLambdaAccessPointAlias
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
The alias of an Object Lambda Access Point. For more information, see [How to use a bucket-style alias for your S3 bucket Object Lambda Access Point].
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/olap-use.html#ol-access-points-alias
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of the Object Lambda Access Point alias.
-
#value ⇒ String
The alias value of the Object Lambda Access Point.
Instance Attribute Details
#status ⇒ String
The status of the Object Lambda Access Point alias. If the status is PROVISIONING, the Object Lambda Access Point is provisioning the alias and the alias is not ready for use yet. If the status is READY, the Object Lambda Access Point alias is successfully provisioned and ready for use.
5760 5761 5762 5763 5764 5765 |
# File 'lib/aws-sdk-s3control/types.rb', line 5760 class ObjectLambdaAccessPointAlias < Struct.new( :value, :status) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The alias value of the Object Lambda Access Point.
5760 5761 5762 5763 5764 5765 |
# File 'lib/aws-sdk-s3control/types.rb', line 5760 class ObjectLambdaAccessPointAlias < Struct.new( :value, :status) SENSITIVE = [] include Aws::Structure end |