Class: Aws::S3Control::Types::ProposedMultiRegionAccessPointPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::ProposedMultiRegionAccessPointPolicy
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
The proposed access control policy for the Multi-Region Access Point.
When you update the policy, the update is first listed as the proposed policy. After the update is finished and all Regions have been updated, the proposed policy is listed as the established policy. If both policies have the same version number, the proposed policy is the established policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The details of the proposed policy.
Instance Attribute Details
#policy ⇒ String
The details of the proposed policy.
5720 5721 5722 5723 5724 |
# File 'lib/aws-sdk-s3control/types.rb', line 5720 class ProposedMultiRegionAccessPointPolicy < Struct.new( :policy) SENSITIVE = [] include Aws::Structure end |