Class: Aws::S3Control::Types::PutAccessGrantsInstanceResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::PutAccessGrantsInstanceResourcePolicyRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
-
#organization ⇒ String
The Organization of the resource policy of the S3 Access Grants instance.
-
#policy ⇒ String
The resource policy of the S3 Access Grants instance that you are updating.
Instance Attribute Details
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
5820 5821 5822 5823 5824 5825 5826 |
# File 'lib/aws-sdk-s3control/types.rb', line 5820 class PutAccessGrantsInstanceResourcePolicyRequest < Struct.new( :account_id, :policy, :organization) SENSITIVE = [] include Aws::Structure end |
#organization ⇒ String
The Organization of the resource policy of the S3 Access Grants instance.
5820 5821 5822 5823 5824 5825 5826 |
# File 'lib/aws-sdk-s3control/types.rb', line 5820 class PutAccessGrantsInstanceResourcePolicyRequest < Struct.new( :account_id, :policy, :organization) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The resource policy of the S3 Access Grants instance that you are updating.
5820 5821 5822 5823 5824 5825 5826 |
# File 'lib/aws-sdk-s3control/types.rb', line 5820 class PutAccessGrantsInstanceResourcePolicyRequest < Struct.new( :account_id, :policy, :organization) SENSITIVE = [] include Aws::Structure end |