Class: Aws::S3Control::Types::PutAccessPointPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::PutAccessPointPolicyRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID for owner of the bucket associated with the specified access point.
-
#name ⇒ String
The name of the access point that you want to associate with the specified policy.
-
#policy ⇒ String
The policy that you want to apply to the specified access point.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID for owner of the bucket associated with the specified access point.
5934 5935 5936 5937 5938 5939 5940 |
# File 'lib/aws-sdk-s3control/types.rb', line 5934 class PutAccessPointPolicyRequest < Struct.new( :account_id, :name, :policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the access point that you want to associate with the specified policy.
For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well.
For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the access point accessed in the format ‘arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/accesspoint/<my-accesspoint-name>`. For example, to access the access point reports-ap through Outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/accesspoint/reports-ap. The value must be URL encoded.
5934 5935 5936 5937 5938 5939 5940 |
# File 'lib/aws-sdk-s3control/types.rb', line 5934 class PutAccessPointPolicyRequest < Struct.new( :account_id, :name, :policy) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The policy that you want to apply to the specified access point. For more information about access point policies, see [Managing data access with Amazon S3 access points] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/access-points.html
5934 5935 5936 5937 5938 5939 5940 |
# File 'lib/aws-sdk-s3control/types.rb', line 5934 class PutAccessPointPolicyRequest < Struct.new( :account_id, :name, :policy) SENSITIVE = [] include Aws::Structure end |