Method: Aws::S3Control::Types::PutAccessPointPolicyRequest#policy

Defined in:
lib/aws-sdk-s3control/types.rb

#policyString

The policy that you want to apply to the specified access point. For more information about access point policies, see [Managing data access with Amazon S3 access points] or [Managing access to shared datasets in directory buckets with access points] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/access-points.html [2]: docs.aws.amazon.com/AmazonS3/latest/userguide/access-points-directory-buckets.html

Returns:

  • (String)


6506
6507
6508
6509
6510
6511
6512
# File 'lib/aws-sdk-s3control/types.rb', line 6506

class PutAccessPointPolicyRequest < Struct.new(
  :account_id,
  :name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end