Class: Aws::S3Control::Types::ReplicationRuleAndOperator
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::ReplicationRuleAndOperator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
A container for specifying rule filters. The filters determine the subset of objects to which the rule applies. This element is required only if you specify more than one filter.
For example:
-
If you specify both a ‘Prefix` and a `Tag` filter, wrap these filters in an `And` element.
-
If you specify a filter based on multiple tags, wrap the ‘Tag` elements in an `And` element.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#prefix ⇒ String
An object key name prefix that identifies the subset of objects that the rule applies to.
-
#tags ⇒ Array<Types::S3Tag>
An array of tags that contain key and value pairs.
Instance Attribute Details
#prefix ⇒ String
An object key name prefix that identifies the subset of objects that the rule applies to.
7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-s3control/types.rb', line 7163 class ReplicationRuleAndOperator < Struct.new( :prefix, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::S3Tag>
An array of tags that contain key and value pairs.
7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-s3control/types.rb', line 7163 class ReplicationRuleAndOperator < Struct.new( :prefix, :tags) SENSITIVE = [] include Aws::Structure end |