Class: Aws::S3Control::Types::S3CopyObjectOperation
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::S3CopyObjectOperation
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Contains the configuration parameters for a PUT Copy object operation. S3 Batch Operations passes every object to the underlying CopyObject API operation. For more information about the parameters for this operation, see [CopyObject].
[1]: docs.aws.amazon.com/AmazonS3/latest/API/RESTObjectCOPY.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_control_grants ⇒ Array<Types::S3Grant>
<note markdown=“1”> This functionality is not supported by directory buckets.
-
#bucket_key_enabled ⇒ Boolean
Specifies whether Amazon S3 should use an S3 Bucket Key for object encryption with server-side encryption using Amazon Web Services KMS (SSE-KMS).
-
#canned_access_control_list ⇒ String
<note markdown=“1”> This functionality is not supported by directory buckets.
-
#checksum_algorithm ⇒ String
Indicates the algorithm that you want Amazon S3 to use to create the checksum.
- #metadata_directive ⇒ String
- #modified_since_constraint ⇒ Time
-
#new_object_metadata ⇒ Types::S3ObjectMetadata
If you don’t provide this parameter, Amazon S3 copies all the metadata from the original objects.
-
#new_object_tagging ⇒ Array<Types::S3Tag>
Specifies a list of tags to add to the destination objects after they are copied.
-
#object_lock_legal_hold_status ⇒ String
The legal hold status to be applied to all objects in the Batch Operations job.
-
#object_lock_mode ⇒ String
The retention mode to be applied to all objects in the Batch Operations job.
-
#object_lock_retain_until_date ⇒ Time
The date when the applied object retention configuration expires on all objects in the Batch Operations job.
-
#redirect_location ⇒ String
If the destination bucket is configured as a website, specifies an optional metadata property for website redirects,
x-amz-website-redirect-location. -
#requester_pays ⇒ Boolean
<note markdown=“1”> This functionality is not supported by directory buckets.
-
#sse_aws_kms_key_id ⇒ String
<note markdown=“1”> This functionality is not supported by directory buckets.
-
#storage_class ⇒ String
Specify the storage class for the destination objects in a
Copyoperation. -
#target_key_prefix ⇒ String
Specifies the folder prefix that you want the objects to be copied into.
-
#target_resource ⇒ String
Specifies the destination bucket Amazon Resource Name (ARN) for the batch copy operation.
- #un_modified_since_constraint ⇒ Time
Instance Attribute Details
#access_control_grants ⇒ Array<Types::S3Grant>
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#bucket_key_enabled ⇒ Boolean
Specifies whether Amazon S3 should use an S3 Bucket Key for object encryption with server-side encryption using Amazon Web Services KMS (SSE-KMS). Setting this header to true causes Amazon S3 to use an S3 Bucket Key for object encryption with SSE-KMS.
Specifying this header with an object action doesn’t affect bucket-level settings for S3 Bucket Key.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#canned_access_control_list ⇒ String
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#checksum_algorithm ⇒ String
Indicates the algorithm that you want Amazon S3 to use to create the checksum. For more information, see [ Checking object integrity] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#metadata_directive ⇒ String
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#modified_since_constraint ⇒ Time
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#new_object_metadata ⇒ Types::S3ObjectMetadata
If you don’t provide this parameter, Amazon S3 copies all the metadata from the original objects. If you specify an empty set, the new objects will have no tags. Otherwise, Amazon S3 assigns the supplied tags to the new objects.
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#new_object_tagging ⇒ Array<Types::S3Tag>
Specifies a list of tags to add to the destination objects after they are copied. If NewObjectTagging is not specified, the tags of the source objects are copied to destination objects by default.
<note markdown=“1”> **Directory buckets** - Tags aren’t supported by directory buckets. If your source objects have tags and your destination bucket is a directory bucket, specify an empty tag set in the NewObjectTagging field to prevent copying the source object tags to the directory bucket.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#object_lock_legal_hold_status ⇒ String
The legal hold status to be applied to all objects in the Batch Operations job.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#object_lock_mode ⇒ String
The retention mode to be applied to all objects in the Batch Operations job.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#object_lock_retain_until_date ⇒ Time
The date when the applied object retention configuration expires on all objects in the Batch Operations job.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#redirect_location ⇒ String
If the destination bucket is configured as a website, specifies an optional metadata property for website redirects, x-amz-website-redirect-location. Allows webpage redirects if the object copy is accessed through a website endpoint.
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#requester_pays ⇒ Boolean
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#sse_aws_kms_key_id ⇒ String
<note markdown=“1”> This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#storage_class ⇒ String
Specify the storage class for the destination objects in a Copy operation.
<note markdown=“1”> Directory buckets - This functionality is not supported by directory buckets.
</note>
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#target_key_prefix ⇒ String
Specifies the folder prefix that you want the objects to be copied into. For example, to copy objects into a folder named Folder1 in the destination bucket, set the TargetKeyPrefix property to Folder1.
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#target_resource ⇒ String
Specifies the destination bucket Amazon Resource Name (ARN) for the batch copy operation.
-
**General purpose buckets** - For example, to copy objects to a general purpose bucket named
destinationBucket, set theTargetResourceproperty toarn:aws:s3:::destinationBucket. -
**Directory buckets** - For example, to copy objects to a directory bucket named
destinationBucketin the Availability Zone; identified by the AZ IDusw2-az2, set theTargetResourceproperty toarn:aws:s3express:region:account_id:/bucket/destination_bucket_base_name--usw2-az2--x-s3.
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |
#un_modified_since_constraint ⇒ Time
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-s3control/types.rb', line 6893 class S3CopyObjectOperation < Struct.new( :target_resource, :canned_access_control_list, :access_control_grants, :metadata_directive, :modified_since_constraint, :new_object_metadata, :new_object_tagging, :redirect_location, :requester_pays, :storage_class, :un_modified_since_constraint, :sse_aws_kms_key_id, :target_key_prefix, :object_lock_legal_hold_status, :object_lock_mode, :object_lock_retain_until_date, :bucket_key_enabled, :checksum_algorithm) SENSITIVE = [] include Aws::Structure end |