Class: Aws::S3Control::Types::S3Retention
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::S3Retention
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Contains the S3 Object Lock retention mode to be applied to all objects in the S3 Batch Operations job. If you don’t provide Mode and RetainUntilDate data types in your operation, you will remove the retention from your objects. For more information, see [Using S3 Object Lock retention with S3 Batch Operations] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-retention-date.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mode ⇒ String
The Object Lock retention mode to be applied to all objects in the Batch Operations job.
-
#retain_until_date ⇒ Time
The date when the applied Object Lock retention will expire on all objects set by the Batch Operations job.
Instance Attribute Details
#mode ⇒ String
The Object Lock retention mode to be applied to all objects in the Batch Operations job.
7246 7247 7248 7249 7250 7251 |
# File 'lib/aws-sdk-s3control/types.rb', line 7246 class S3Retention < Struct.new( :retain_until_date, :mode) SENSITIVE = [] include Aws::Structure end |
#retain_until_date ⇒ Time
The date when the applied Object Lock retention will expire on all objects set by the Batch Operations job.
7246 7247 7248 7249 7250 7251 |
# File 'lib/aws-sdk-s3control/types.rb', line 7246 class S3Retention < Struct.new( :retain_until_date, :mode) SENSITIVE = [] include Aws::Structure end |