Class: Aws::S3Control::Types::S3SetObjectRetentionOperation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Contains the configuration parameters for the Object Lock retention action for an S3 Batch Operations job. Batch Operations passes every object to the underlying PutObjectRetention API operation. For more information, see [Using S3 Object Lock retention with S3 Batch Operations] in the *Amazon S3 User Guide*.

<note markdown=“1”> This functionality is not supported by directory buckets.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-retention-date.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bypass_governance_retentionBoolean

Indicates if the action should be applied to objects in the Batch Operations job even if they have Object Lock ‘ GOVERNANCE` type in place.

Returns:

  • (Boolean)


8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-s3control/types.rb', line 8019

class S3SetObjectRetentionOperation < Struct.new(
  :bypass_governance_retention,
  :retention)
  SENSITIVE = []
  include Aws::Structure
end

#retentionTypes::S3Retention

Contains the Object Lock retention mode to be applied to all objects in the Batch Operations job. For more information, see [Using S3 Object Lock retention with S3 Batch Operations] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-retention-date.html

Returns:



8019
8020
8021
8022
8023
8024
# File 'lib/aws-sdk-s3control/types.rb', line 8019

class S3SetObjectRetentionOperation < Struct.new(
  :bypass_governance_retention,
  :retention)
  SENSITIVE = []
  include Aws::Structure
end