Class: Aws::S3Control::Types::SSEKMSEncryption

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Configuration for the use of SSE-KMS to encrypt generated manifest objects.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_idString

Specifies the ID of the Amazon Web Services Key Management Service (Amazon Web Services KMS) symmetric encryption customer managed key to use for encrypting generated manifest objects.



7593
7594
7595
7596
7597
# File 'lib/aws-sdk-s3control/types.rb', line 7593

class SSEKMSEncryption < Struct.new(
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end