Class: Aws::S3Control::Types::StorageLensConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::StorageLensConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
A container for the Amazon S3 Storage Lens configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_level ⇒ Types::AccountLevel
A container for all the account-level configurations of your S3 Storage Lens configuration.
-
#aws_org ⇒ Types::StorageLensAwsOrg
A container for the Amazon Web Services organization for this S3 Storage Lens configuration.
-
#data_export ⇒ Types::StorageLensDataExport
A container to specify the properties of your S3 Storage Lens metrics export including, the destination, schema and format.
-
#exclude ⇒ Types::Exclude
A container for what is excluded in this configuration.
-
#expanded_prefixes_data_export ⇒ Types::StorageLensExpandedPrefixesDataExport
A container that configures your S3 Storage Lens expanded prefixes metrics report.
-
#id ⇒ String
A container for the Amazon S3 Storage Lens configuration ID.
-
#include ⇒ Types::Include
A container for what is included in this configuration.
-
#is_enabled ⇒ Boolean
A container for whether the S3 Storage Lens configuration is enabled.
-
#prefix_delimiter ⇒ String
A container for all prefix delimiters that are used for object keys in this S3 Storage Lens configuration.
-
#storage_lens_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 Storage Lens configuration.
Instance Attribute Details
#account_level ⇒ Types::AccountLevel
A container for all the account-level configurations of your S3 Storage Lens configuration.
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#aws_org ⇒ Types::StorageLensAwsOrg
A container for the Amazon Web Services organization for this S3 Storage Lens configuration.
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#data_export ⇒ Types::StorageLensDataExport
A container to specify the properties of your S3 Storage Lens metrics export including, the destination, schema and format.
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#exclude ⇒ Types::Exclude
A container for what is excluded in this configuration. This container can only be valid if there is no ‘Include` container submitted, and it’s not empty.
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#expanded_prefixes_data_export ⇒ Types::StorageLensExpandedPrefixesDataExport
A container that configures your S3 Storage Lens expanded prefixes metrics report.
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A container for the Amazon S3 Storage Lens configuration ID.
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#include ⇒ Types::Include
A container for what is included in this configuration. This container can only be valid if there is no ‘Exclude` container submitted, and it’s not empty.
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#is_enabled ⇒ Boolean
A container for whether the S3 Storage Lens configuration is enabled.
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#prefix_delimiter ⇒ String
A container for all prefix delimiters that are used for object keys in this S3 Storage Lens configuration. The prefix delimiters determine how S3 Storage Lens counts prefix depth, by separating the hierarchical levels in object keys.
<note markdown=“1”> * If either a prefix delimiter or existing delimiter is undefined,
Amazon S3 uses the delimiter that’s defined.
-
If both the prefix delimiter and existing delimiter are undefined, S3 uses ‘/` as the default delimiter.
-
When custom delimiters are used, both the prefix delimiter and existing delimiter must specify the same special character. Otherwise, your request results in an error.
</note>
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |
#storage_lens_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 Storage Lens configuration. This property is read-only and follows the following format: ‘ arn:aws:s3:us-east-1:example-account-id:storage-lens/your-dashboard-name `
8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-s3control/types.rb', line 8420 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :expanded_prefixes_data_export, :is_enabled, :aws_org, :storage_lens_arn, :prefix_delimiter) SENSITIVE = [] include Aws::Structure end |