Class: Aws::S3Control::Types::StorageLensGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::StorageLensGroup
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
A custom grouping of objects that include filters for prefixes, suffixes, object tags, object size, or object age. You can create an S3 Storage Lens group that includes a single filter or multiple filter conditions. To specify multiple filter conditions, you use AND or OR logical operators.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::StorageLensGroupFilter
Sets the criteria for the Storage Lens group data that is displayed.
-
#name ⇒ String
Contains the name of the Storage Lens group.
-
#storage_lens_group_arn ⇒ String
Contains the Amazon Resource Name (ARN) of the Storage Lens group.
Instance Attribute Details
#filter ⇒ Types::StorageLensGroupFilter
Sets the criteria for the Storage Lens group data that is displayed. For multiple filter conditions, the AND or OR logical operator is used.
7910 7911 7912 7913 7914 7915 7916 |
# File 'lib/aws-sdk-s3control/types.rb', line 7910 class StorageLensGroup < Struct.new( :name, :filter, :storage_lens_group_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Contains the name of the Storage Lens group.
7910 7911 7912 7913 7914 7915 7916 |
# File 'lib/aws-sdk-s3control/types.rb', line 7910 class StorageLensGroup < Struct.new( :name, :filter, :storage_lens_group_arn) SENSITIVE = [] include Aws::Structure end |
#storage_lens_group_arn ⇒ String
Contains the Amazon Resource Name (ARN) of the Storage Lens group. This property is read-only.
7910 7911 7912 7913 7914 7915 7916 |
# File 'lib/aws-sdk-s3control/types.rb', line 7910 class StorageLensGroup < Struct.new( :name, :filter, :storage_lens_group_arn) SENSITIVE = [] include Aws::Structure end |