Class: Aws::S3Control::Types::StorageLensGroupOrOperator
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::StorageLensGroupOrOperator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
A container element for specifying Or rule conditions. The rule
conditions determine the subset of objects to which the Or rule
applies. Objects can match any of the listed filter conditions, which
are joined by the Or logical operator. Only one of each filter
condition is allowed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#match_any_prefix ⇒ Array<String>
Filters objects that match any of the specified prefixes.
-
#match_any_suffix ⇒ Array<String>
Filters objects that match any of the specified suffixes.
-
#match_any_tag ⇒ Array<Types::S3Tag>
Filters objects that match any of the specified S3 object tags.
-
#match_object_age ⇒ Types::MatchObjectAge
Filters objects that match the specified object age range.
-
#match_object_size ⇒ Types::MatchObjectSize
Filters objects that match the specified object size range.
Instance Attribute Details
#match_any_prefix ⇒ Array<String>
Filters objects that match any of the specified prefixes.
8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-s3control/types.rb', line 8799 class StorageLensGroupOrOperator < Struct.new( :match_any_prefix, :match_any_suffix, :match_any_tag, :match_object_age, :match_object_size) SENSITIVE = [] include Aws::Structure end |
#match_any_suffix ⇒ Array<String>
Filters objects that match any of the specified suffixes.
8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-s3control/types.rb', line 8799 class StorageLensGroupOrOperator < Struct.new( :match_any_prefix, :match_any_suffix, :match_any_tag, :match_object_age, :match_object_size) SENSITIVE = [] include Aws::Structure end |
#match_any_tag ⇒ Array<Types::S3Tag>
Filters objects that match any of the specified S3 object tags.
8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-s3control/types.rb', line 8799 class StorageLensGroupOrOperator < Struct.new( :match_any_prefix, :match_any_suffix, :match_any_tag, :match_object_age, :match_object_size) SENSITIVE = [] include Aws::Structure end |
#match_object_age ⇒ Types::MatchObjectAge
Filters objects that match the specified object age range.
8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-s3control/types.rb', line 8799 class StorageLensGroupOrOperator < Struct.new( :match_any_prefix, :match_any_suffix, :match_any_tag, :match_object_age, :match_object_size) SENSITIVE = [] include Aws::Structure end |
#match_object_size ⇒ Types::MatchObjectSize
Filters objects that match the specified object size range.
8799 8800 8801 8802 8803 8804 8805 8806 8807 |
# File 'lib/aws-sdk-s3control/types.rb', line 8799 class StorageLensGroupOrOperator < Struct.new( :match_any_prefix, :match_any_suffix, :match_any_tag, :match_object_age, :match_object_size) SENSITIVE = [] include Aws::Structure end |