Class: Aws::S3Control::Types::StorageLensTableDestination

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

A container for configuring your S3 Storage Lens reports to export to read-only S3 table buckets. This parameter enables you to store your Storage Lens metrics in a structured, queryable table format in Apache Iceberg.

For more information about S3 Storage Lens, see Assessing your storage activity and usage with S3 Storage Lens in the Amazon S3 User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryptionTypes::StorageLensDataExportEncryption

A container for the encryption of the S3 Storage Lens metrics exports.



8836
8837
8838
8839
8840
8841
# File 'lib/aws-sdk-s3control/types.rb', line 8836

class StorageLensTableDestination < Struct.new(
  :is_enabled,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end

#is_enabledBoolean

A container that indicates whether the export to read-only S3 table buckets is enabled for your S3 Storage Lens configuration. When set to true, Storage Lens reports are automatically exported to tables in addition to other configured destinations.



8836
8837
8838
8839
8840
8841
# File 'lib/aws-sdk-s3control/types.rb', line 8836

class StorageLensTableDestination < Struct.new(
  :is_enabled,
  :encryption)
  SENSITIVE = []
  include Aws::Structure
end