Class: Aws::S3Control::Types::UpdateAccessGrantsLocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::UpdateAccessGrantsLocationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_grants_location_id ⇒ String
The ID of the registered location that you are updating.
-
#account_id ⇒ String
The Amazon Web Services account ID of the S3 Access Grants instance.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role for the registered location.
Instance Attribute Details
#access_grants_location_id ⇒ String
The ID of the registered location that you are updating. S3 Access
Grants assigns this ID when you register the location. S3 Access
Grants assigns the ID default to the default location s3:// and
assigns an auto-generated ID to other locations that you register.
The ID of the registered location to which you are granting access.
S3 Access Grants assigned this ID when you registered the location.
S3 Access Grants assigns the ID default to the default location
s3:// and assigns an auto-generated ID to other locations that you
register.
If you are passing the default location, you cannot create an
access grant for the entire default location. You must also specify
a bucket or a bucket and prefix in the Subprefix field.
9077 9078 9079 9080 9081 9082 9083 |
# File 'lib/aws-sdk-s3control/types.rb', line 9077 class UpdateAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id, :iam_role_arn) SENSITIVE = [] include Aws::Structure end |
#account_id ⇒ String
The Amazon Web Services account ID of the S3 Access Grants instance.
9077 9078 9079 9080 9081 9082 9083 |
# File 'lib/aws-sdk-s3control/types.rb', line 9077 class UpdateAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id, :iam_role_arn) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role for the registered location. S3 Access Grants assumes this role to manage access to the registered location.
9077 9078 9079 9080 9081 9082 9083 |
# File 'lib/aws-sdk-s3control/types.rb', line 9077 class UpdateAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id, :iam_role_arn) SENSITIVE = [] include Aws::Structure end |