Class: Aws::S3Control::Types::UpdateAccessGrantsLocationResult

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_grants_location_arnString

The Amazon Resource Name (ARN) of the registered location that you are updating.

Returns:

  • (String)


8134
8135
8136
8137
8138
8139
8140
8141
8142
# File 'lib/aws-sdk-s3control/types.rb', line 8134

class UpdateAccessGrantsLocationResult < Struct.new(
  :created_at,
  :access_grants_location_id,
  :access_grants_location_arn,
  :location_scope,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#access_grants_location_idString

The ID of the registered location to which you are granting access. S3 Access Grants assigned this ID when you registered the location. S3 Access Grants assigns the ID default to the default location s3:// and assigns an auto-generated ID to other locations that you register.

Returns:

  • (String)


8134
8135
8136
8137
8138
8139
8140
8141
8142
# File 'lib/aws-sdk-s3control/types.rb', line 8134

class UpdateAccessGrantsLocationResult < Struct.new(
  :created_at,
  :access_grants_location_id,
  :access_grants_location_arn,
  :location_scope,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when you registered the location.

Returns:

  • (Time)


8134
8135
8136
8137
8138
8139
8140
8141
8142
# File 'lib/aws-sdk-s3control/types.rb', line 8134

class UpdateAccessGrantsLocationResult < Struct.new(
  :created_at,
  :access_grants_location_id,
  :access_grants_location_arn,
  :location_scope,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

The Amazon Resource Name (ARN) of the IAM role of the registered location. S3 Access Grants assumes this role to manage access to the registered location.

Returns:

  • (String)


8134
8135
8136
8137
8138
8139
8140
8141
8142
# File 'lib/aws-sdk-s3control/types.rb', line 8134

class UpdateAccessGrantsLocationResult < Struct.new(
  :created_at,
  :access_grants_location_id,
  :access_grants_location_arn,
  :location_scope,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#location_scopeString

The S3 URI path of the location that you are updating. You cannot update the scope of the registered location. The location scope can be the default S3 location s3://, the S3 path to a bucket ‘s3://<bucket>`, or the S3 path to a bucket and prefix `s3://<bucket>/<prefix>`.

Returns:

  • (String)


8134
8135
8136
8137
8138
8139
8140
8141
8142
# File 'lib/aws-sdk-s3control/types.rb', line 8134

class UpdateAccessGrantsLocationResult < Struct.new(
  :created_at,
  :access_grants_location_id,
  :access_grants_location_arn,
  :location_scope,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end