Method: Aws::S3Control::Types::CreateAccessGrantRequest#grantee
- Defined in:
- lib/aws-sdk-s3control/types.rb
#grantee ⇒ Types::Grantee
The user, group, or role to which you are granting access. You can grant access to an IAM user or role. If you have added your corporate directory to Amazon Web Services IAM Identity Center and associated your Identity Center instance with your S3 Access Grants instance, the grantee can also be a corporate directory user or group.
668 669 670 671 672 673 674 675 676 677 678 679 |
# File 'lib/aws-sdk-s3control/types.rb', line 668 class CreateAccessGrantRequest < Struct.new( :account_id, :access_grants_location_id, :access_grants_location_configuration, :grantee, :permission, :application_arn, :s3_prefix_type, :tags) SENSITIVE = [] include Aws::Structure end |