Class: Aws::S3Control::Types::CreateMultiRegionAccessPointInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::CreateMultiRegionAccessPointInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
A container for the information associated with a
- CreateMultiRegionAccessPoint][1
-
request.
[1]: docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateMultiRegionAccessPoint.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the Multi-Region Access Point associated with this request.
-
#public_access_block ⇒ Types::PublicAccessBlockConfiguration
The
PublicAccessBlockconfiguration that you want to apply to this Amazon S3 account. -
#regions ⇒ Array<Types::Region>
The buckets in different Regions that are associated with the Multi-Region Access Point.
Instance Attribute Details
#name ⇒ String
The name of the Multi-Region Access Point associated with this request.
1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/aws-sdk-s3control/types.rb', line 1254 class CreateMultiRegionAccessPointInput < Struct.new( :name, :public_access_block, :regions) SENSITIVE = [] include Aws::Structure end |
#public_access_block ⇒ Types::PublicAccessBlockConfiguration
The PublicAccessBlock configuration that you want to apply to this Amazon S3 account. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see [The Meaning of “Public“] in the *Amazon S3 User Guide*.
This data type is not supported for Amazon S3 on Outposts.
1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/aws-sdk-s3control/types.rb', line 1254 class CreateMultiRegionAccessPointInput < Struct.new( :name, :public_access_block, :regions) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<Types::Region>
The buckets in different Regions that are associated with the Multi-Region Access Point.
1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/aws-sdk-s3control/types.rb', line 1254 class CreateMultiRegionAccessPointInput < Struct.new( :name, :public_access_block, :regions) SENSITIVE = [] include Aws::Structure end |