Class: Aws::S3Control::Types::Credentials

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

The Amazon Web Services Security Token Service temporary credential that S3 Access Grants vends to grantees and client applications.

Constant Summary collapse

SENSITIVE =
[:access_key_id, :secret_access_key, :session_token]

Instance Attribute Summary collapse

Instance Attribute Details

#access_key_idString

The unique access key ID of the Amazon Web Services STS temporary credential that S3 Access Grants vends to grantees and client applications.



1360
1361
1362
1363
1364
1365
1366
1367
# File 'lib/aws-sdk-s3control/types.rb', line 1360

class Credentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = [:access_key_id, :secret_access_key, :session_token]
  include Aws::Structure
end

#expirationTime

The expiration date and time of the temporary credential that S3 Access Grants vends to grantees and client applications.



1360
1361
1362
1363
1364
1365
1366
1367
# File 'lib/aws-sdk-s3control/types.rb', line 1360

class Credentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = [:access_key_id, :secret_access_key, :session_token]
  include Aws::Structure
end

#secret_access_keyString

The secret access key of the Amazon Web Services STS temporary credential that S3 Access Grants vends to grantees and client applications.



1360
1361
1362
1363
1364
1365
1366
1367
# File 'lib/aws-sdk-s3control/types.rb', line 1360

class Credentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = [:access_key_id, :secret_access_key, :session_token]
  include Aws::Structure
end

#session_tokenString

The Amazon Web Services STS temporary credential that S3 Access Grants vends to grantees and client applications.



1360
1361
1362
1363
1364
1365
1366
1367
# File 'lib/aws-sdk-s3control/types.rb', line 1360

class Credentials < Struct.new(
  :access_key_id,
  :secret_access_key,
  :session_token,
  :expiration)
  SENSITIVE = [:access_key_id, :secret_access_key, :session_token]
  include Aws::Structure
end