Method: Aws::S3Control::Types::Destination#access_control_translation
- Defined in:
- lib/aws-sdk-s3control/types.rb
#access_control_translation ⇒ Types::AccessControlTranslation
Specify this property only in a cross-account scenario (where the source and destination bucket owners are not the same), and you want to change replica ownership to the Amazon Web Services account that owns the destination bucket. If this property is not specified in the replication configuration, the replicas are owned by same Amazon Web Services account that owns the source object.
<note markdown=“1”> This is not supported by Amazon S3 on Outposts buckets.
</note>
2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 |
# File 'lib/aws-sdk-s3control/types.rb', line 2172 class Destination < Struct.new( :account, :bucket, :replication_time, :access_control_translation, :encryption_configuration, :metrics, :storage_class) SENSITIVE = [] include Aws::Structure end |