Class: Aws::S3Control::Types::GetAccessGrantsInstanceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::GetAccessGrantsInstanceResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_grants_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 Access Grants instance.
-
#access_grants_instance_id ⇒ String
The ID of the S3 Access Grants instance.
-
#created_at ⇒ Time
The date and time when you created the S3 Access Grants instance.
-
#identity_center_arn ⇒ String
If you associated your S3 Access Grants instance with an Amazon Web Services IAM Identity Center instance, this field returns the Amazon Resource Name (ARN) of the Amazon Web Services IAM Identity Center instance application; a subresource of the original Identity Center instance.
Instance Attribute Details
#access_grants_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 Access Grants instance.
2366 2367 2368 2369 2370 2371 2372 2373 |
# File 'lib/aws-sdk-s3control/types.rb', line 2366 class GetAccessGrantsInstanceResult < Struct.new( :access_grants_instance_arn, :access_grants_instance_id, :identity_center_arn, :created_at) SENSITIVE = [] include Aws::Structure end |
#access_grants_instance_id ⇒ String
The ID of the S3 Access Grants instance. The ID is default. You can have one S3 Access Grants instance per Region per account.
2366 2367 2368 2369 2370 2371 2372 2373 |
# File 'lib/aws-sdk-s3control/types.rb', line 2366 class GetAccessGrantsInstanceResult < Struct.new( :access_grants_instance_arn, :access_grants_instance_id, :identity_center_arn, :created_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when you created the S3 Access Grants instance.
2366 2367 2368 2369 2370 2371 2372 2373 |
# File 'lib/aws-sdk-s3control/types.rb', line 2366 class GetAccessGrantsInstanceResult < Struct.new( :access_grants_instance_arn, :access_grants_instance_id, :identity_center_arn, :created_at) SENSITIVE = [] include Aws::Structure end |
#identity_center_arn ⇒ String
If you associated your S3 Access Grants instance with an Amazon Web Services IAM Identity Center instance, this field returns the Amazon Resource Name (ARN) of the Amazon Web Services IAM Identity Center instance application; a subresource of the original Identity Center instance. S3 Access Grants creates this Identity Center application for the specific S3 Access Grants instance.
2366 2367 2368 2369 2370 2371 2372 2373 |
# File 'lib/aws-sdk-s3control/types.rb', line 2366 class GetAccessGrantsInstanceResult < Struct.new( :access_grants_instance_arn, :access_grants_instance_id, :identity_center_arn, :created_at) SENSITIVE = [] include Aws::Structure end |