Class: Aws::S3Control::Types::GetAccessGrantsLocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::GetAccessGrantsLocationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_grants_location_id ⇒ String
The ID of the registered location that you are retrieving.
-
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
Instance Attribute Details
#access_grants_location_id ⇒ String
The ID of the registered location that you are retrieving. S3 Access Grants assigns this ID when you register the location. S3 Access Grants assigns the ID default to the default location s3:// and assigns an auto-generated ID to other locations that you register.
2389 2390 2391 2392 2393 2394 |
# File 'lib/aws-sdk-s3control/types.rb', line 2389 class GetAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id) SENSITIVE = [] include Aws::Structure end |
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
2389 2390 2391 2392 2393 2394 |
# File 'lib/aws-sdk-s3control/types.rb', line 2389 class GetAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id) SENSITIVE = [] include Aws::Structure end |