Class: Aws::S3Control::Types::GetAccessPointResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::GetAccessPointResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_point_arn ⇒ String
The ARN of the access point.
-
#alias ⇒ String
The name or alias of the access point.
-
#bucket ⇒ String
The name of the bucket associated with the specified access point.
-
#bucket_account_id ⇒ String
The Amazon Web Services account ID associated with the S3 bucket associated with this access point.
-
#creation_date ⇒ Time
The date and time when the specified access point was created.
-
#endpoints ⇒ Hash<String,String>
The VPC endpoint for the access point.
-
#name ⇒ String
The name of the specified access point.
-
#network_origin ⇒ String
Indicates whether this access point allows access from the public internet.
-
#public_access_block_configuration ⇒ Types::PublicAccessBlockConfiguration
The
PublicAccessBlockconfiguration that you want to apply to this Amazon S3 account. -
#vpc_configuration ⇒ Types::VpcConfiguration
Contains the virtual private cloud (VPC) configuration for the specified access point.
Instance Attribute Details
#access_point_arn ⇒ String
The ARN of the access point.
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#alias ⇒ String
The name or alias of the access point.
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#bucket ⇒ String
The name of the bucket associated with the specified access point.
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#bucket_account_id ⇒ String
The Amazon Web Services account ID associated with the S3 bucket associated with this access point.
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time when the specified access point was created.
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Hash<String,String>
The VPC endpoint for the access point.
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the specified access point.
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#network_origin ⇒ String
Indicates whether this access point allows access from the public internet. If VpcConfiguration is specified for this access point, then NetworkOrigin is VPC, and the access point doesn’t allow access from the public internet. Otherwise, NetworkOrigin is Internet, and the access point allows access from the public internet, subject to the access point and bucket access policies.
This will always be true for an Amazon S3 on Outposts access point
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#public_access_block_configuration ⇒ Types::PublicAccessBlockConfiguration
The PublicAccessBlock configuration that you want to apply to this Amazon S3 account. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see [The Meaning of “Public“] in the *Amazon S3 User Guide*.
This data type is not supported for Amazon S3 on Outposts.
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |
#vpc_configuration ⇒ Types::VpcConfiguration
Contains the virtual private cloud (VPC) configuration for the specified access point.
<note markdown=“1”> This element is empty if this access point is an Amazon S3 on Outposts access point that is used by other Amazon Web Services.
</note>
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 |
# File 'lib/aws-sdk-s3control/types.rb', line 2755 class GetAccessPointResult < Struct.new( :name, :bucket, :network_origin, :vpc_configuration, :public_access_block_configuration, :creation_date, :alias, :access_point_arn, :endpoints, :bucket_account_id) SENSITIVE = [] include Aws::Structure end |