Class: Aws::S3Control::Types::GetBucketVersioningResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::GetBucketVersioningResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mfa_delete ⇒ String
Specifies whether MFA delete is enabled in the bucket versioning configuration.
-
#status ⇒ String
The versioning state of the S3 on Outposts bucket.
Instance Attribute Details
#mfa_delete ⇒ String
Specifies whether MFA delete is enabled in the bucket versioning configuration. This element is returned only if the bucket has been configured with MFA delete. If MFA delete has never been configured for the bucket, this element is not returned.
3021 3022 3023 3024 3025 3026 |
# File 'lib/aws-sdk-s3control/types.rb', line 3021 class GetBucketVersioningResult < Struct.new( :status, :mfa_delete) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The versioning state of the S3 on Outposts bucket.
3021 3022 3023 3024 3025 3026 |
# File 'lib/aws-sdk-s3control/types.rb', line 3021 class GetBucketVersioningResult < Struct.new( :status, :mfa_delete) SENSITIVE = [] include Aws::Structure end |