Class: Aws::S3Control::Types::ListCallerAccessGrantsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::ListCallerAccessGrantsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID of the S3 Access Grants instance.
-
#allowed_by_application ⇒ Boolean
If this optional parameter is passed in the request, a filter is applied to the results.
-
#grant_scope ⇒ String
The S3 path of the data that you would like to access.
-
#max_results ⇒ Integer
The maximum number of access grants that you would like returned in the
List Caller Access Grantsresponse. -
#next_token ⇒ String
A pagination token to request the next page of results.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID of the S3 Access Grants instance.
5326 5327 5328 5329 5330 5331 5332 5333 5334 |
# File 'lib/aws-sdk-s3control/types.rb', line 5326 class ListCallerAccessGrantsRequest < Struct.new( :account_id, :grant_scope, :next_token, :max_results, :allowed_by_application) SENSITIVE = [] include Aws::Structure end |
#allowed_by_application ⇒ Boolean
If this optional parameter is passed in the request, a filter is
applied to the results. The results will include only the access
grants for the caller's Identity Center application or for any
other applications (ALL).
5326 5327 5328 5329 5330 5331 5332 5333 5334 |
# File 'lib/aws-sdk-s3control/types.rb', line 5326 class ListCallerAccessGrantsRequest < Struct.new( :account_id, :grant_scope, :next_token, :max_results, :allowed_by_application) SENSITIVE = [] include Aws::Structure end |
#grant_scope ⇒ String
The S3 path of the data that you would like to access. Must start
with s3://. You can optionally pass only the beginning characters
of a path, and S3 Access Grants will search for all applicable
grants for the path fragment.
5326 5327 5328 5329 5330 5331 5332 5333 5334 |
# File 'lib/aws-sdk-s3control/types.rb', line 5326 class ListCallerAccessGrantsRequest < Struct.new( :account_id, :grant_scope, :next_token, :max_results, :allowed_by_application) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of access grants that you would like returned in
the List Caller Access Grants response. If the results include the
pagination token NextToken, make another call using the
NextToken to determine if there are more results.
5326 5327 5328 5329 5330 5331 5332 5333 5334 |
# File 'lib/aws-sdk-s3control/types.rb', line 5326 class ListCallerAccessGrantsRequest < Struct.new( :account_id, :grant_scope, :next_token, :max_results, :allowed_by_application) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token to request the next page of results. Pass this
value into a subsequent List Caller Access Grants request in order
to retrieve the next page of results.
5326 5327 5328 5329 5330 5331 5332 5333 5334 |
# File 'lib/aws-sdk-s3control/types.rb', line 5326 class ListCallerAccessGrantsRequest < Struct.new( :account_id, :grant_scope, :next_token, :max_results, :allowed_by_application) SENSITIVE = [] include Aws::Structure end |