Class: Aws::S3Control::Types::ListRegionalBucketsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::ListRegionalBucketsResult
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
NextTokenis sent whenisTruncatedis true, which means there are more buckets that can be listed. - #regional_bucket_list ⇒ Array<Types::RegionalBucket>
Instance Attribute Details
#next_token ⇒ String
NextToken is sent when isTruncated is true, which means there are more buckets that can be listed. The next list requests to Amazon S3 can be continued with this NextToken. NextToken is obfuscated and is not a real key.
5488 5489 5490 5491 5492 5493 |
# File 'lib/aws-sdk-s3control/types.rb', line 5488 class ListRegionalBucketsResult < Struct.new( :regional_bucket_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#regional_bucket_list ⇒ Array<Types::RegionalBucket>
5488 5489 5490 5491 5492 5493 |
# File 'lib/aws-sdk-s3control/types.rb', line 5488 class ListRegionalBucketsResult < Struct.new( :regional_bucket_list, :next_token) SENSITIVE = [] include Aws::Structure end |