Method: Aws::S3Control::Types::PublicAccessBlockConfiguration#block_public_acls
- Defined in:
- lib/aws-sdk-s3control/types.rb
#block_public_acls ⇒ Boolean
Specifies whether Amazon S3 should block public access control lists (ACLs) for buckets in this account. Setting this element to TRUE causes the following behavior:
-
PutBucketAclandPutObjectAclcalls fail if the specified ACL is public. -
PUT Object calls fail if the request includes a public ACL.
-
PUT Bucket calls fail if the request includes a public ACL.
Enabling this setting doesn’t affect existing policies or ACLs.
This property is not supported for Amazon S3 on Outposts.
6365 6366 6367 6368 6369 6370 6371 6372 |
# File 'lib/aws-sdk-s3control/types.rb', line 6365 class PublicAccessBlockConfiguration < Struct.new( :block_public_acls, :ignore_public_acls, :block_public_policy, :restrict_public_buckets) SENSITIVE = [] include Aws::Structure end |