Class: Aws::S3Control::Types::ReplicationRuleAndOperator
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::ReplicationRuleAndOperator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
A container for specifying rule filters. The filters determine the subset of objects to which the rule applies. This element is required only if you specify more than one filter.
For example:
-
If you specify both a
Prefixand aTagfilter, wrap these filters in anAndelement. -
If you specify a filter based on multiple tags, wrap the
Tagelements in anAndelement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#prefix ⇒ String
An object key name prefix that identifies the subset of objects that the rule applies to.
-
#tags ⇒ Array<Types::S3Tag>
An array of tags that contain key and value pairs.
Instance Attribute Details
#prefix ⇒ String
An object key name prefix that identifies the subset of objects that the rule applies to.
6754 6755 6756 6757 6758 6759 |
# File 'lib/aws-sdk-s3control/types.rb', line 6754 class ReplicationRuleAndOperator < Struct.new( :prefix, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::S3Tag>
An array of tags that contain key and value pairs.
6754 6755 6756 6757 6758 6759 |
# File 'lib/aws-sdk-s3control/types.rb', line 6754 class ReplicationRuleAndOperator < Struct.new( :prefix, :tags) SENSITIVE = [] include Aws::Structure end |