Class: Aws::S3Control::Types::S3JobManifestGenerator
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::S3JobManifestGenerator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
The container for the service that will create the S3 manifest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_manifest_output ⇒ Boolean
Determines whether or not to write the job’s generated manifest to a bucket.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the bucket the generated manifest is written to.
-
#filter ⇒ Types::JobManifestGeneratorFilter
Specifies rules the S3JobManifestGenerator should use to decide whether an object in the source bucket should or should not be included in the generated job manifest.
-
#manifest_output_location ⇒ Types::S3ManifestOutputLocation
Specifies the location the generated manifest will be written to.
-
#source_bucket ⇒ String
The ARN of the source bucket used by the ManifestGenerator.
Instance Attribute Details
#enable_manifest_output ⇒ Boolean
Determines whether or not to write the job’s generated manifest to a bucket.
7747 7748 7749 7750 7751 7752 7753 7754 7755 |
# File 'lib/aws-sdk-s3control/types.rb', line 7747 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the bucket the generated manifest is written to. If provided the generated manifest bucket’s owner Amazon Web Services account ID must match this value, else the job fails.
7747 7748 7749 7750 7751 7752 7753 7754 7755 |
# File 'lib/aws-sdk-s3control/types.rb', line 7747 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::JobManifestGeneratorFilter
Specifies rules the S3JobManifestGenerator should use to decide whether an object in the source bucket should or should not be included in the generated job manifest.
7747 7748 7749 7750 7751 7752 7753 7754 7755 |
# File 'lib/aws-sdk-s3control/types.rb', line 7747 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |
#manifest_output_location ⇒ Types::S3ManifestOutputLocation
Specifies the location the generated manifest will be written to. Manifests can’t be written to directory buckets. For more information, see [Directory buckets].
[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/directory-buckets-overview.html
7747 7748 7749 7750 7751 7752 7753 7754 7755 |
# File 'lib/aws-sdk-s3control/types.rb', line 7747 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |
#source_bucket ⇒ String
The ARN of the source bucket used by the ManifestGenerator.
<note markdown=“1”> **Directory buckets** - Directory buckets aren’t supported as the source buckets used by S3JobManifestGenerator to generate the job manifest.
</note>
7747 7748 7749 7750 7751 7752 7753 7754 7755 |
# File 'lib/aws-sdk-s3control/types.rb', line 7747 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |