Class: Aws::S3Control::Types::S3JobManifestGenerator
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::S3JobManifestGenerator
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
The container for the service that will create the S3 manifest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_manifest_output ⇒ Boolean
Determines whether or not to write the job's generated manifest to a bucket.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the source bucket specified in
SourceBucket. -
#filter ⇒ Types::JobManifestGeneratorFilter
Specifies rules the S3JobManifestGenerator should use to decide whether an object in the source bucket should or should not be included in the generated job manifest.
-
#manifest_output_location ⇒ Types::S3ManifestOutputLocation
Specifies the location the generated manifest will be written to.
-
#source_bucket ⇒ String
The ARN of the source bucket used by the ManifestGenerator.
Instance Attribute Details
#enable_manifest_output ⇒ Boolean
Determines whether or not to write the job's generated manifest to a bucket.
7789 7790 7791 7792 7793 7794 7795 7796 7797 |
# File 'lib/aws-sdk-s3control/types.rb', line 7789 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the source bucket
specified in SourceBucket. If provided, the manifest source bucket
owner's Amazon Web Services account ID must match this value, else
the job fails.
7789 7790 7791 7792 7793 7794 7795 7796 7797 |
# File 'lib/aws-sdk-s3control/types.rb', line 7789 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::JobManifestGeneratorFilter
Specifies rules the S3JobManifestGenerator should use to decide whether an object in the source bucket should or should not be included in the generated job manifest.
7789 7790 7791 7792 7793 7794 7795 7796 7797 |
# File 'lib/aws-sdk-s3control/types.rb', line 7789 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |
#manifest_output_location ⇒ Types::S3ManifestOutputLocation
Specifies the location the generated manifest will be written to. Manifests can't be written to directory buckets. For more information, see Directory buckets.
7789 7790 7791 7792 7793 7794 7795 7796 7797 |
# File 'lib/aws-sdk-s3control/types.rb', line 7789 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |
#source_bucket ⇒ String
The ARN of the source bucket used by the ManifestGenerator.
S3JobManifestGenerator to generate the job
manifest.
7789 7790 7791 7792 7793 7794 7795 7796 7797 |
# File 'lib/aws-sdk-s3control/types.rb', line 7789 class S3JobManifestGenerator < Struct.new( :expected_bucket_owner, :source_bucket, :manifest_output_location, :filter, :enable_manifest_output) SENSITIVE = [] include Aws::Structure end |