Class: Aws::S3Control::Types::S3SetObjectLegalHoldOperation

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Contains the configuration for an S3 Object Lock legal hold operation that an S3 Batch Operations job passes to every object to the underlying PutObjectLegalHold API operation. For more information, see [Using S3 Object Lock legal hold with S3 Batch Operations] in the *Amazon S3 User Guide*.

<note markdown=“1”> This functionality is not supported by directory buckets.

</note>

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-legal-hold.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

Contains the Object Lock legal hold status to be applied to all objects in the Batch Operations job.



7294
7295
7296
7297
7298
# File 'lib/aws-sdk-s3control/types.rb', line 7294

class S3SetObjectLegalHoldOperation < Struct.new(
  :legal_hold)
  SENSITIVE = []
  include Aws::Structure
end