Class: Aws::S3Control::Types::StorageLensConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::StorageLensConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
A container for the Amazon S3 Storage Lens configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_level ⇒ Types::AccountLevel
A container for all the account-level configurations of your S3 Storage Lens configuration.
-
#aws_org ⇒ Types::StorageLensAwsOrg
A container for the Amazon Web Services organization for this S3 Storage Lens configuration.
-
#data_export ⇒ Types::StorageLensDataExport
A container to specify the properties of your S3 Storage Lens metrics export including, the destination, schema and format.
-
#exclude ⇒ Types::Exclude
A container for what is excluded in this configuration.
-
#id ⇒ String
A container for the Amazon S3 Storage Lens configuration ID.
-
#include ⇒ Types::Include
A container for what is included in this configuration.
-
#is_enabled ⇒ Boolean
A container for whether the S3 Storage Lens configuration is enabled.
-
#storage_lens_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 Storage Lens configuration.
Instance Attribute Details
#account_level ⇒ Types::AccountLevel
A container for all the account-level configurations of your S3 Storage Lens configuration.
7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 |
# File 'lib/aws-sdk-s3control/types.rb', line 7830 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :is_enabled, :aws_org, :storage_lens_arn) SENSITIVE = [] include Aws::Structure end |
#aws_org ⇒ Types::StorageLensAwsOrg
A container for the Amazon Web Services organization for this S3 Storage Lens configuration.
7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 |
# File 'lib/aws-sdk-s3control/types.rb', line 7830 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :is_enabled, :aws_org, :storage_lens_arn) SENSITIVE = [] include Aws::Structure end |
#data_export ⇒ Types::StorageLensDataExport
A container to specify the properties of your S3 Storage Lens metrics export including, the destination, schema and format.
7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 |
# File 'lib/aws-sdk-s3control/types.rb', line 7830 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :is_enabled, :aws_org, :storage_lens_arn) SENSITIVE = [] include Aws::Structure end |
#exclude ⇒ Types::Exclude
A container for what is excluded in this configuration. This container can only be valid if there is no Include container submitted, and it’s not empty.
7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 |
# File 'lib/aws-sdk-s3control/types.rb', line 7830 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :is_enabled, :aws_org, :storage_lens_arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A container for the Amazon S3 Storage Lens configuration ID.
7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 |
# File 'lib/aws-sdk-s3control/types.rb', line 7830 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :is_enabled, :aws_org, :storage_lens_arn) SENSITIVE = [] include Aws::Structure end |
#include ⇒ Types::Include
A container for what is included in this configuration. This container can only be valid if there is no Exclude container submitted, and it’s not empty.
7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 |
# File 'lib/aws-sdk-s3control/types.rb', line 7830 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :is_enabled, :aws_org, :storage_lens_arn) SENSITIVE = [] include Aws::Structure end |
#is_enabled ⇒ Boolean
A container for whether the S3 Storage Lens configuration is enabled.
7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 |
# File 'lib/aws-sdk-s3control/types.rb', line 7830 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :is_enabled, :aws_org, :storage_lens_arn) SENSITIVE = [] include Aws::Structure end |
#storage_lens_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 Storage Lens configuration. This property is read-only and follows the following format: ‘ arn:aws:s3:us-east-1:example-account-id:storage-lens/your-dashboard-name `
7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 |
# File 'lib/aws-sdk-s3control/types.rb', line 7830 class StorageLensConfiguration < Struct.new( :id, :account_level, :include, :exclude, :data_export, :is_enabled, :aws_org, :storage_lens_arn) SENSITIVE = [] include Aws::Structure end |