Class: Aws::S3Control::Types::StorageLensGroupLevel

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Specifies the Storage Lens groups to include in the Storage Lens group aggregation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#selection_criteriaTypes::StorageLensGroupLevelSelectionCriteria

Indicates which Storage Lens group ARNs to include or exclude in the Storage Lens group aggregation. If this value is left null, then all Storage Lens groups are selected.



7781
7782
7783
7784
7785
# File 'lib/aws-sdk-s3control/types.rb', line 7781

class StorageLensGroupLevel < Struct.new(
  :selection_criteria)
  SENSITIVE = []
  include Aws::Structure
end