Class: Aws::S3Control::Types::StorageLensGroupLevelSelectionCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::StorageLensGroupLevelSelectionCriteria
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Indicates which Storage Lens group ARNs to include or exclude in the Storage Lens group aggregation. You can only attach Storage Lens groups to your Storage Lens dashboard if they’re included in your Storage Lens group aggregation. If this value is left null, then all Storage Lens groups are selected.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exclude ⇒ Array<String>
Indicates which Storage Lens group ARNs to exclude from the Storage Lens group aggregation.
-
#include ⇒ Array<String>
Indicates which Storage Lens group ARNs to include in the Storage Lens group aggregation.
Instance Attribute Details
#exclude ⇒ Array<String>
Indicates which Storage Lens group ARNs to exclude from the Storage Lens group aggregation.
8675 8676 8677 8678 8679 8680 |
# File 'lib/aws-sdk-s3control/types.rb', line 8675 class StorageLensGroupLevelSelectionCriteria < Struct.new( :include, :exclude) SENSITIVE = [] include Aws::Structure end |
#include ⇒ Array<String>
Indicates which Storage Lens group ARNs to include in the Storage Lens group aggregation.
8675 8676 8677 8678 8679 8680 |
# File 'lib/aws-sdk-s3control/types.rb', line 8675 class StorageLensGroupLevelSelectionCriteria < Struct.new( :include, :exclude) SENSITIVE = [] include Aws::Structure end |