Class: Aws::S3Control::Types::Transition
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::Transition
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Specifies when an object transitions to a specified storage class. For more information about Amazon S3 Lifecycle configuration rules, see [ Transitioning objects using Amazon S3 Lifecycle] in the *Amazon S3 User Guide*.
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/lifecycle-transition-general-considerations.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#date ⇒ Time
Indicates when objects are transitioned to the specified storage class.
-
#days ⇒ Integer
Indicates the number of days after creation when objects are transitioned to the specified storage class.
-
#storage_class ⇒ String
The storage class to which you want the object to transition.
Instance Attribute Details
#date ⇒ Time
Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.
8272 8273 8274 8275 8276 8277 8278 |
# File 'lib/aws-sdk-s3control/types.rb', line 8272 class Transition < Struct.new( :date, :days, :storage_class) SENSITIVE = [] include Aws::Structure end |
#days ⇒ Integer
Indicates the number of days after creation when objects are transitioned to the specified storage class. The value must be a positive integer.
8272 8273 8274 8275 8276 8277 8278 |
# File 'lib/aws-sdk-s3control/types.rb', line 8272 class Transition < Struct.new( :date, :days, :storage_class) SENSITIVE = [] include Aws::Structure end |
#storage_class ⇒ String
The storage class to which you want the object to transition.
8272 8273 8274 8275 8276 8277 8278 |
# File 'lib/aws-sdk-s3control/types.rb', line 8272 class Transition < Struct.new( :date, :days, :storage_class) SENSITIVE = [] include Aws::Structure end |