Class: Aws::S3Control::Types::Transition

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3control/types.rb

Overview

Specifies when an object transitions to a specified storage class. For more information about Amazon S3 Lifecycle configuration rules, see [ Transitioning objects using Amazon S3 Lifecycle] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/dev/lifecycle-transition-general-considerations.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dateTime

Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.



8026
8027
8028
8029
8030
8031
8032
# File 'lib/aws-sdk-s3control/types.rb', line 8026

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#daysInteger

Indicates the number of days after creation when objects are transitioned to the specified storage class. The value must be a positive integer.



8026
8027
8028
8029
8030
8031
8032
# File 'lib/aws-sdk-s3control/types.rb', line 8026

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

The storage class to which you want the object to transition.



8026
8027
8028
8029
8030
8031
8032
# File 'lib/aws-sdk-s3control/types.rb', line 8026

class Transition < Struct.new(
  :date,
  :days,
  :storage_class)
  SENSITIVE = []
  include Aws::Structure
end