Class: Aws::S3Control::Types::UpdateAccessGrantsLocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::UpdateAccessGrantsLocationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_grants_location_id ⇒ String
The ID of the registered location that you are updating.
-
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role for the registered location.
Instance Attribute Details
#access_grants_location_id ⇒ String
The ID of the registered location that you are updating. S3 Access Grants assigns this ID when you register the location. S3 Access Grants assigns the ID default to the default location s3:// and assigns an auto-generated ID to other locations that you register.
The ID of the registered location to which you are granting access. S3 Access Grants assigned this ID when you registered the location. S3 Access Grants assigns the ID default to the default location s3:// and assigns an auto-generated ID to other locations that you register.
If you are passing the default location, you cannot create an access grant for the entire default location. You must also specify a bucket or a bucket and prefix in the Subprefix field.
8093 8094 8095 8096 8097 8098 8099 |
# File 'lib/aws-sdk-s3control/types.rb', line 8093 class UpdateAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id, :iam_role_arn) SENSITIVE = [] include Aws::Structure end |
#account_id ⇒ String
The ID of the Amazon Web Services account that is making this request.
8093 8094 8095 8096 8097 8098 8099 |
# File 'lib/aws-sdk-s3control/types.rb', line 8093 class UpdateAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id, :iam_role_arn) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role for the registered location. S3 Access Grants assumes this role to manage access to the registered location.
8093 8094 8095 8096 8097 8098 8099 |
# File 'lib/aws-sdk-s3control/types.rb', line 8093 class UpdateAccessGrantsLocationRequest < Struct.new( :account_id, :access_grants_location_id, :iam_role_arn) SENSITIVE = [] include Aws::Structure end |