Class: Aws::S3Control::Types::UpdateJobStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::S3Control::Types::UpdateJobStatusRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-s3control/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account ID associated with the S3 Batch Operations job.
-
#job_id ⇒ String
The ID of the job whose status you want to update.
-
#requested_job_status ⇒ String
The status that you want to move the specified job to.
-
#status_update_reason ⇒ String
A description of the reason why you want to change the specified job’s status.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account ID associated with the S3 Batch Operations job.
8205 8206 8207 8208 8209 8210 8211 8212 |
# File 'lib/aws-sdk-s3control/types.rb', line 8205 class UpdateJobStatusRequest < Struct.new( :account_id, :job_id, :requested_job_status, :status_update_reason) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The ID of the job whose status you want to update.
8205 8206 8207 8208 8209 8210 8211 8212 |
# File 'lib/aws-sdk-s3control/types.rb', line 8205 class UpdateJobStatusRequest < Struct.new( :account_id, :job_id, :requested_job_status, :status_update_reason) SENSITIVE = [] include Aws::Structure end |
#requested_job_status ⇒ String
The status that you want to move the specified job to.
8205 8206 8207 8208 8209 8210 8211 8212 |
# File 'lib/aws-sdk-s3control/types.rb', line 8205 class UpdateJobStatusRequest < Struct.new( :account_id, :job_id, :requested_job_status, :status_update_reason) SENSITIVE = [] include Aws::Structure end |
#status_update_reason ⇒ String
A description of the reason why you want to change the specified job’s status. This field can be any string up to the maximum length.
8205 8206 8207 8208 8209 8210 8211 8212 |
# File 'lib/aws-sdk-s3control/types.rb', line 8205 class UpdateJobStatusRequest < Struct.new( :account_id, :job_id, :requested_job_status, :status_update_reason) SENSITIVE = [] include Aws::Structure end |